import site;
import os
os.system("pip install jupyterlab_templates")
os.system("jupyter labextension install jupyterlab_templates")
os.system("jupyter serverextension enable --py jupyterlab_templates")
def main():
    print("Running Jupyter platform!") 
    out=site.getsitepackages()
    str_out = out   
    out1=' '.join(str_out)  
    filename =  os.path.join(out1, "finai_mac", "jupyter_notebook_config.py")
    filename2 = filename.replace(os.sep, '/')    
    os.system("jupyter lab --config=" + filename2)
   

if __name__ == "__main__":
    main()


def listToString(s): 
    
    # initialize an empty string
    str1 = "" 
    
    # traverse in the string  
    for ele in s: 
        str1 += ele  
    
    # return string  
    return str1 


#!/usr/bin/env python
# coding: utf-8

# Copyright (c) Juptyer Development Team.
# Distributed under the terms of the Modified BSD License.

#-----------------------------------------------------------------------------
# Minimal Python version sanity check (from IPython/Jupyterhub)
#-----------------------------------------------------------------------------

from __future__ import print_function

import os
import sys

from setuptools import setup

pjoin = os.path.join
here = os.path.abspath(os.path.dirname(__file__))

# Get the current package version.
version_ns = {}
with open(pjoin(here, 'version.py')) as f:
    exec(f.read(), {}, version_ns)

setup_args = dict(
    name                = 'finai_mac',
    packages            = ['finai_mac'],
    version             = "2.0",
    description         = """REMOTE_USER Authenticator: An Authenticator for Jupyterhub to read user information from HTTP request headers, as when running behind an authenticating proxy.""",
    long_description    = "",
    author              = "Manav (https://github.com/manavmisra2)",
    author_email        = "manavmisra2@gmail.com",
    url                 = "https://github.com/manavmisra2/finai_mac.git",
    license             = "GPLv3",
    platforms           = "Linux, Mac OS X",
    keywords            = ['Interactive', 'Interpreter', 'Shell', 'Web'],
    classifiers         = [
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
    ],
    data_files          = [('.', ['version.py'])],
    # scripts=['bin/run_finai_mac'],	
    entry_points = {
        "console_scripts": [
            "myscript = finai_mac.__main__:main",
        ]
    }	
)

# setuptools requirements
if 'setuptools' in sys.modules:
    setup_args['install_requires'] = install_requires = []
    install_requires.append('jupyterlab')

def main():
    setup(**setup_args)

if __name__ == '__main__':
    main()
